@@ -43,14 +43,14 @@ sim.glm <- function(object, n.sims=100){
 
 
 sim.mer <- function(object, n.sims=100){
-#    object <- summary(object)
-#    if (lapply(object@bVar,sum)<=0|sum(unlist(lapply(object@bVar, is.na)))>0){
-#        object@call$control <- list(usePQL=TRUE)
-#        object <- lmer(object@call$formula)
-#    }
-    sc <- attr (VarCorr (object), "sc")
+    #object <- summary(object)
+    if (lapply(object@bVar,sum)<=0|sum(unlist(lapply(object@bVar, is.na)))>0){
+        object@call$control <- list(usePQL=TRUE)
+        object <- lmer(object@call$formula)
+    }
+    sc <- attr (VarCorr (object), "sc")  
     # simulate unmodeled coefficients
-    fcoef <- .Call("mer_fixef", object, PACKAGE = "lme4")
+    fcoef <- fixef(object)
     corF <- vcov(object)@factors$correlation
     se.unmodeled <- corF@sd
     V.beta <- (se.unmodeled %o% se.unmodeled) * as.matrix(corF)
@@ -96,15 +96,15 @@ sim.mer2 <- function(object, n.sims=100){
     # simulate coefficients within groups
     sc <- attr (VarCorr (object), "sc")  # scale
     coef <- ranef (object)
-    vars <- object@bVar      #???? str(ranef(object, postVar=TRUE))????
-    beta.bygroup <- vars
-    n.groupings <- length (vars)
+    estimate <- ranef(object, postVar=TRUE)
+    beta.bygroup <- NULL
+    n.groupings <- length (coef)
     for (m in 1:n.groupings){
-      vars.m <- vars[[m]]
+      bhat <- estimate[[m]]
+      vars.m <- attr (estimate[[m]], "postVar")
       K <- dim(vars.m)[1]
       J <- dim(vars.m)[3]
       beta.bygroup[[m]] <- array (NA, c(n.sims, J, K))
-      bhat <- ranef(object)[[m]]
       for (j in 1:J){
         V.beta <- untriangle(vars.m[,,j])*sc^2
         beta.bygroup[[m]][,j,] <- mvrnorm (n.sims, bhat[j,], V.beta)
